| getProducts | R Documentation |
getProducts requests product specific data from the appFigures API.
getProducts(product_id, store = c("all", "apple", "google_play",
"amazon", "windows"), curlHandle, verbose = FALSE, orgJSON = FALSE)
product_id |
Either the string value |
store |
A character string to filter products by store. Defaults to "all" stores. |
curlHandle |
Provide an instance of the CURLHandle-class from the RCurl package. The default will create a curl handle specific to the function call. |
verbose |
Logical. Should details of the web request print to the
console? Defaults to |
orgJSON |
Logical. Should the JSON string be returned without being
converted to R objects? Defaults to |
Products represent a trackable item in the appFigures system.
Products can be an app as well as an in-app purchase or book. The user can
request data on all their products by setting the id variable to
"mine". Data for products can be requested by either their store
specific ids or by their appFigures-assigned ids. If more than one product_id
is supplied, the requests are made concurrently.
A data frame containing all publicly available fields.
Official documentation: http://docs.appfigures.com/products.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.